@@ -10,9 +10,30 @@
 '''
 import numpy as np
 import matplotlib.pyplot as plt
+from matplotlib.collections import PolyCollection
 import LFPy
 from mpi4py import MPI
 
+#Fetch Mainen&Sejnowski 1996 model files
+if not os.path.isfile('patdemo/cells/j4a.hoc'):
+    #get the model files:
+    u = urllib2.urlopen('http://senselab.med.yale.edu/ModelDB/eavBinDown.asp?o=2488&a=23&mime=application/zip')
+    localFile = open('patdemo.zip', 'w')
+    localFile.write(u.read())
+    localFile.close()
+    #unzip:
+    myzip = zipfile.ZipFile('patdemo.zip', 'r')
+    myzip.extractall('.')
+    myzip.close()
+
+#compile mod files every time, because of incompatibility with Hay2011 files:
+os.system('''
+          cd patdemo
+          nrnivmodl
+          ''')
+#os.system('nrnivmodl')
+LFPy.cell.neuron.load_mechanisms('patdemo')
+
 #set one global seed, ensure all randomizations are set on RANK 0 in script!
 np.random.seed(12345)
 
@@ -60,14 +81,14 @@ class Population:
         
         #superimpose local LFPs on every RANK, then sum using MPI to RANK 0
         self.LFP = []
-        for key, value in self.results.iteritems():
+        for key, value in self.results.items():
             self.LFP.append(value['LFP'])
         self.LFP = np.array(self.LFP).sum(axis=0)
         self.LFP = COMM.reduce(self.LFP)        #LFP is None on all but RANK 0
         
         #collect all simulation results on RANK 0, including single cell LFP
         if RANK == 0:
-            for i in xrange(1, SIZE):
+            for i in range(1, SIZE):
                 result = COMM.recv(source=MPI.ANY_SOURCE) #receive from ANY rank
                 self.results.update(result)     #collect
         else:
@@ -81,7 +102,7 @@ class Population:
         #start unique cell simulation on every RANK,
         #and store the electrode and cell objects in dicts indexed by cellindex
         results = {}
-        for cellindex in xrange(self.POPULATION_SIZE):
+        for cellindex in range(self.POPULATION_SIZE):
             if divmod(cellindex, SIZE)[1] == RANK:
                 results.update({cellindex : self.cellsim(cellindex)})
         return results
@@ -90,7 +111,7 @@ class Population:
         '''draw and distribute some spike times for each cell in population'''
         if RANK == 0:
             RandSpikeTimes = []
-            for cellindex in xrange(self.POPULATION_SIZE):
+            for cellindex in range(self.POPULATION_SIZE):
                 sptimes = LFPy.inputgenerators.stationary_gamma(
                     self.cellParameters['tstartms'],
                     self.cellParameters['tstopms'],
@@ -106,7 +127,7 @@ class Population:
         cylinder constraints'''
         if RANK == 0:
             cellPositions = []
-            for cellindex in xrange(self.POPULATION_SIZE):
+            for cellindex in range(self.POPULATION_SIZE):
                 r = np.sqrt(np.random.rand()) * \
                                     self.populationParameters['radius']
                 theta = np.random.rand() * 2 * np.pi
@@ -160,46 +181,56 @@ class Population:
         if RANK == 0:
             fig = plt.figure(figsize=(12, 8))
             
-            ax = fig.add_subplot(121, aspect='equal', frameon=False,
+            ax = fig.add_axes([0.05, 0.0, 0.45, 1.0],
+                        aspect='equal', frameon=False,
                         xticks=[], xticklabels=[], yticks=[], yticklabels=[])
-            for cellindex in xrange(self.POPULATION_SIZE):
+            for cellindex in range(self.POPULATION_SIZE):
                 cell = LFPy.Cell(**self.cellParameters)
                 cell.set_pos(xpos = self.cellPositions[cellindex, 0],
                      ypos = self.cellPositions[cellindex, 1],
                      zpos = self.cellPositions[cellindex, 2])
                 cell.set_rotation(z = self.cellRotations[cellindex])
-                for sec in LFPy.cell.neuron.h.allsec():
-                    idx = cell.get_idx(sec.name())
-                    ax.plot(np.r_[cell.xstart[idx], cell.xend[idx][-1]],
-                            np.r_[cell.zstart[idx], cell.zend[idx][-1]],
-                            color='bgrcmykbgrcmykbgrcmyk'[cellindex])
+
+                zips = []
+                for x, z in cell.get_idx_polygons():
+                    zips.append(zip(x, z))
+                
+                polycol = PolyCollection(zips,
+                                edgecolors='none',
+                                facecolors='bgrcmykbgrcmykbgrcmyk'[cellindex],
+                                zorder = self.cellPositions[cellindex, 1])
+       
+                ax.add_collection(polycol)
+
             ax.plot(self.electrodeParameters['x'],
-                    self.electrodeParameters['z'], '.', marker='o', color='g')
+                    self.electrodeParameters['z'],
+                    marker='o', color='g', clip_on=False, zorder=0)
             
-            ax = fig.add_subplot(222)
-            for key, value in self.results.iteritems():
+            ax = fig.add_axes([0.5, 0.55, 0.40, 0.4])
+            for key, value in self.results.items():
                 tvec = np.arange(value['somav'].size) * \
                                         self.cellParameters['timeres_python']
                 ax.plot(tvec, value['somav'],
                         label = 'cell %i' % key)
             leg = ax.legend()
-            ax.set_xlabel('time (ms)')
+            #ax.set_xlabel('time (ms)')
             ax.set_ylabel('$V_{soma}$ (mV)')
             ax.set_title('somatic potentials')
             
-            ax = fig.add_subplot(224)
+            ax = fig.add_axes([0.5, 0.075, 0.40, 0.4])
+            cax = fig.add_axes([0.91, 0.075, 0.02, 0.40])
             im = ax.pcolormesh(tvec, self.electrodeParameters['z'], self.LFP,
                            cmap='spectral_r',
                            vmin = -abs(self.LFP).max(),
                            vmax = abs(self.LFP).max())
             ax.axis(ax.axis('tight'))
-            cbar = plt.colorbar(im)
+            cbar = plt.colorbar(im, cax=cax)
             cbar.set_label('LFP (mV)')
             ax.set_title('superimposed LFP')
             ax.set_xlabel('time (ms)')
             ax.set_ylabel('$z$ ($\mu$m)')
             
-            fig.savefig('example_mpi.pdf')
+            fig.savefig('example_mpi.png', dpi=300)
         
 
 if __name__ == '__main__':
@@ -214,7 +245,7 @@ if __name__ == '__main__':
         'e_pas' : -65,              # reversal potential passive mechs
         'passive' : True,           # switch on passive mechs
         'nsegs_method' : 'lambda_f',# method for setting number of segments,
-        'lambda_f' : 1,           # segments are isopotential at frequency
+        'lambda_f' : 10,            # segments are isopotential at frequency
         'timeres_NEURON' : 2**-3,   # dt of LFP and NEURON simulation.
         'timeres_python' : 2**-3,
         'tstartms' : -100,          #start time, recorders start at t=0
@@ -244,7 +275,7 @@ if __name__ == '__main__':
     # calculated as the average LFP in n random points on each contact:
     X, Y, Z = np.mgrid[0:1, 0:1, -500:1001:50]
     N = np.zeros((X.size, 3))
-    for i in xrange(N.shape[0]): N[i,] = [1, 0, 0] #normal unit vec. to contacts
+    for i in range(N.shape[0]): N[i,] = [1, 0, 0] #normal unit vec. to contacts
     # put parameters in dictionary
     electrodeParameters = {
         'sigma' : 0.3,              # Extracellular potential
