@@ -7,6 +7,8 @@ import numpy as np
 from scipy.integrate import quad
 from scipy import real, imag
 import LFPy
+import neuron
+from warnings import warn
 
 class testLFPy(unittest.TestCase):
     '''
@@ -31,12 +33,12 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
     
@@ -50,12 +52,12 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
     
@@ -69,12 +71,70 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
+                self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
+                                           places=3)
+
+
+    def test_method_pointsource_dotprodcoeffs(self):
+        #create LFPs using LFPy-model
+        LFP_LFPy = self.stickSimulationDotprodcoeffs(method='pointsource')
+        
+        #create LFPs using the analytical approac
+        time = np.linspace(0, 100, 10001)
+        R = np.ones(11)*100
+        Z = np.linspace(1000, 0, 11)
+        
+        LFP_analytic = np.empty((R.size, time.size))
+        for i in range(R.size):
+            LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
+                                                    electrodeZ=Z[i])
+        (a, b) = LFP_LFPy.shape
+        for i in range(a):
+            for j in range(b):
+                self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
+                                           places=3)
+    
+    def test_method_linesource_dotprodcoeffs(self):
+        #create LFPs using LFPy-model
+        LFP_LFPy = self.stickSimulationDotprodcoeffs(method='linesource')
+        
+        #create LFPs using the analytical approac
+        time = np.linspace(0, 100, 10001)
+        R = np.ones(11)*100
+        Z = np.linspace(1000, 0, 11)
+        
+        LFP_analytic = np.empty((R.size, time.size))
+        for i in range(R.size):
+            LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
+                                                    electrodeZ=Z[i])
+        (a, b) = LFP_LFPy.shape
+        for i in range(a):
+            for j in range(b):
+                self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
+                                           places=3)
+    
+    def test_method_som_as_point_dotprodcoeffs(self):
+        #create LFPs using LFPy-model
+        LFP_LFPy = self.stickSimulationDotprodcoeffs(method='som_as_point')
+        
+        #create LFPs using the analytical approac
+        time = np.linspace(0, 100, 10001)
+        R = np.ones(11)*100
+        Z = np.linspace(1000, 0, 11)
+        
+        LFP_analytic = np.empty((R.size, time.size))
+        for i in range(R.size):
+            LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
+                                                    electrodeZ=Z[i])
+        (a, b) = LFP_LFPy.shape
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
 
@@ -90,12 +150,12 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
     
@@ -110,12 +170,12 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
 
@@ -130,12 +190,12 @@ class testLFPy(unittest.TestCase):
         Z = np.linspace(1000, 0, 11)
         
         LFP_analytic = np.empty((R.size, time.size))
-        for i in xrange(R.size):
+        for i in range(R.size):
             LFP_analytic[i, ] = self.analytical_LFP(time, electrodeR=R[i],
                                                     electrodeZ=Z[i])
         (a, b) = LFP_LFPy.shape
-        for i in xrange(a):
-            for j in xrange(b):
+        for i in range(a):
+            for j in range(b):
                 self.failUnlessAlmostEqual(LFP_LFPy[i, j], LFP_analytic[i, j],
                                            places=3)
 
@@ -166,7 +226,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_02(self):
@@ -196,7 +256,7 @@ class testLFPy(unittest.TestCase):
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertEqual(tvec[i], tvec_numpy[i])
 
 
@@ -214,7 +274,6 @@ class testLFPy(unittest.TestCase):
         
         self.assertEqual(tvec.size, tvec_numpy.size)
     
-    @unittest.expectedFailure    
     def test_tvec_05(self):
         stickParams = {
             'timeres_python' : 0.1,
@@ -227,7 +286,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertAlmostEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_06(self):
@@ -244,7 +303,6 @@ class testLFPy(unittest.TestCase):
         
         self.assertEqual(tvec.size, tvec_numpy.size)
     
-    @unittest.expectedFailure
     def test_tvec_07(self):
         stickParams = {
             'timeres_python' : 0.10,
@@ -257,7 +315,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_08(self):
@@ -287,7 +345,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_10(self):
@@ -317,7 +375,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_12(self):
@@ -334,7 +392,6 @@ class testLFPy(unittest.TestCase):
         
         self.assertEqual(tvec.size, tvec_numpy.size)
 
-    @unittest.expectedFailure    
     def test_tvec_13(self):
         stickParams = {
             'timeres_python' : 0.10,
@@ -347,7 +404,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertAlmostEqual(tvec[i], tvec_numpy[i])
 
     def test_tvec_14(self):
@@ -364,7 +421,6 @@ class testLFPy(unittest.TestCase):
         
         self.assertEqual(tvec.size, tvec_numpy.size)
 
-    @unittest.expectedFailure    
     def test_tvec_15(self):
         stickParams = {
             'timeres_python' : 0.10,
@@ -377,7 +433,7 @@ class testLFPy(unittest.TestCase):
         tvec_numpy = np.linspace(0, stickParams['tstopms'],
                     stickParams['tstopms']/stickParams['timeres_python'] + 1)
         
-        for i in xrange(tvec.size):
+        for i in range(tvec.size):
             self.assertAlmostEqual(tvec[i], tvec_numpy[i])    
     
     ######## Functions used by tests: ##########################################
@@ -448,7 +504,7 @@ class testLFPy(unittest.TestCase):
         }
         
         N = np.empty((11, 3))
-        for i in xrange(N.shape[0]): N[i,] = [1, 0, 0] #normal unit vec. to contacts
+        for i in range(N.shape[0]): N[i,] = [1, 0, 0] #normal unit vec. to contacts
         electrodeParams = {
             'sigma' : 0.3,
             'x' : np.ones(11) * 100.,
@@ -482,6 +538,59 @@ class testLFPy(unittest.TestCase):
         
         return electrode.LFP
 
+    def stickSimulationDotprodcoeffs(self, method):
+        stickParams = {
+            'morphology' : 'stick.hoc',
+            'rm' : 30000,
+            'cm' : 1,
+            'Ra' : 150,
+            'tstartms' : -100,
+            'tstopms' : 100,
+            'timeres_python' : 0.01,
+            'timeres_NEURON' : 0.01,
+            'nsegs_method' : 'lambda_f',
+            'lambda_f' : 100,
+            
+        }
+        
+        electrodeParams = {
+            'sigma' : 0.3,
+            'x' : np.ones(11) * 100.,
+            'y' : np.zeros(11),
+            'z' : np.linspace(1000, 0, 11),
+            'method' : method
+        }
+        
+        stimParams = {
+            'pptype' : 'SinSyn',
+            'delay' : -100.,
+            'dur' : 1000.,
+            'pkamp' : 1.,
+            'freq' : 100.,
+            'phase' : -np.pi/2,
+            'bias' : 0.,
+            'record_current' : True
+        }
+        
+        
+        
+        stick = LFPy.Cell(**stickParams)
+        #dummy variables for mapping
+        stick.imem = np.eye(stick.totnsegs)
+        stick.tvec = np.arange(stick.totnsegs)*stick.timeres_python
+        
+        electrode = LFPy.RecExtElectrode(stick, **electrodeParams)
+        electrode.calc_lfp()
+        #not needed anymore:
+        del stick.imem, stick.tvec
+        
+        synapse = LFPy.StimIntElectrode(stick, stick.get_closest_idx(0, 0, 1000),
+                               **stimParams)
+        stick.simulate(dotprodcoeffs=electrode.LFP,
+                       rec_imem=True, rec_istim=True, rec_vmem=True)
+        
+        return stick.dotprodresults[0]
+
     
     def analytical_LFP(self, time=np.linspace(0, 100, 1001),
                        stickLength=1000.,
@@ -571,5 +680,16 @@ class testLFPy(unittest.TestCase):
         return real_integral[0] + 1j*imag_integral[0]
 
 
-suite = unittest.TestLoader().loadTestsFromTestCase(testLFPy)
-unittest.TextTestRunner(verbosity=2).run(suite)
+if __name__ == '__main__':
+    #check if sinsyn.mod is compiled, if it isn't try and run nrnivmodl on it
+    if not hasattr(neuron.h, 'SinSyn'):
+        print __file__
+        import os
+        os.system('nrnivmodl')
+        neuron.load_mechanisms('.')
+    if not hasattr(neuron.h, 'SinSyn'):
+        warn('tests will fail because nrnivmodl did not compile sinsyn.mod')
+        
+
+    suite = unittest.TestLoader().loadTestsFromTestCase(testLFPy)
+    unittest.TextTestRunner(verbosity=2).run(suite)
